==> flutter_payphone-0.0.6.tar.gz: lib/flutter_payphone.dart <==
library flutter_payphone;

import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;

class Payphone {
  String tokenApiKey;

  Payphone(this.tokenApiKey);

  Future<Map<String, dynamic>> saleRequest(
      phoneNumber, amount, amountWithTax, tax, clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale';
    var response = await http.post(
      url,
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'Authorization': tokenApiKey,
      },
      body: jsonEncode(<String, dynamic>{
        if (phoneNumber != null) 'phoneNumber': phoneNumber,
        'countryCode': "593",
        /* Ecuador */
        if (amount != null)
          'amount': amount,
        if (amountWithTax != null) 'amountWithTax': amountWithTax,
        if (tax != null) 'tax': tax,
        if (clientTransactionId != null)
          'clientTransactionId': clientTransactionId,
        'optionalParameter1':
            "Transacción procesada con el plugin para flutter: flutter_payphone"
      }),
    );

    return json.decode(response.body);
  }

  Future<Map<String, dynamic>> saleStatus(clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale/client/' +
        clientTransactionId;
    var response = await http.get(
      url,
      headers: {
        'Accept': 'application/json',
        'Authorization': tokenApiKey,
      },
    );
    return json.decode(response.body);
  }
}

==> flutter_payphone-0.0.7.tar.gz: lib/flutter_payphone.dart <==
library flutter_payphone;

import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;

class Payphone {
  String tokenApiKey;

  Payphone(this.tokenApiKey);

  Future<Map<String, dynamic>> saleRequest(
      phoneNumber, amount, amountWithTax, tax, clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale';
    var response = await http.post(
      url,
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
        'Authorization': 'Bearer '+tokenApiKey,
      },
      body: jsonEncode(<String, dynamic>{
        if (phoneNumber != null) 'phoneNumber': phoneNumber,
        'countryCode': "593",
        /* Ecuador */
        if (amount != null)
          'amount': amount,
        if (amountWithTax != null) 'amountWithTax': amountWithTax,
        if (tax != null) 'tax': tax,
        if (clientTransactionId != null)
          'clientTransactionId': clientTransactionId,
        'optionalParameter1':
            "Transacción procesada con el plugin para flutter: flutter_payphone"
      }),
    );

    return json.decode(response.body);
  }

  Future<List<dynamic>> saleStatus(clientTransactionId) async {
    var url = 'https://pay.payphonetodoesposible.com/api/Sale/client/' +
        clientTransactionId;
    var response = await http.get(
      url,
      headers: {
        'Accept': 'application/json',
        'Authorization': 'Bearer '+tokenApiKey,
      },
    );
    return json.decode(response.body);
  }
}
